# frozen_string_literal: true
require 'test_helper'

class AuthControllerTest < ActionDispatch::IntegrationTest
  include TestAuthHelper

  test "Should fake login process" do
    # This is not a real test of AuthController!
    # We are really testing that the monkey patch is correct
    #
    # This simply tests to make sure the test suite is
    # properly monkey patching the oAuth network call and
    # faking the needed session variables.
    #
    # If you want to really test the oAuth flow you will need to
    # hit the real services, or stand up a proper fake service.
    get auth_path
    assert_redirected_to accounts_path
  end

  test "should verify callbacks result" do
    # If AuthController#callback ever changes final
    # redirection, the patched version should also
    # be updated in (lin e10) of
    # test/test_helpers/test_auth_helper.rb

    assert_equal "redirect_to accounts_path", last_line_in_callback
  end

  test 'should logout' do
    get auth_path
    assert session[:token]

    get logout_path
    assert session[:token].nil?
    assert_redirected_to login_path
  end
end
